.. simeon documentation master file, created by
   sphinx-quickstart on Sat Feb 27 08:34:04 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Documentation for the simeon CLI tool
======================================

CLI Guide
~~~~~~~~~~~~~~~~~~~
Documentation for users of the ``simeon`` CLI tool.

.. toctree::
   :maxdepth: 2

   cli_intro

Python API Guide
~~~~~~~~~~~~~~~~~~~
Documentation for contributing to the package, and for those wishing to add ``simeon`` to their python dependencies.

.. toctree::
   :maxdepth: 3

   api_intro


